//Source file: TodayNowHelper.java

import java.util.*;
import java.text.*;

public class TodayNowHelper {
    private Date m_date;
    // the formatter will be set if there is a format string as argument, 
    // otherwise it will remain until not changed by setFormatter()
    private SimpleDateFormat m_formatter;
    public static final String defaultFormat = "d.M.y";

    public TodayNowHelper(Date p_date, String p_formString) { 
	m_date = p_date;
        m_formatter = new SimpleDateFormat(p_formString);
    }
    public TodayNowHelper(String p_formString, String p_arg) throws Exception { 
	this(parseDate(p_formString, p_arg),p_formString);
    }
    public TodayNowHelper(String p_arg) throws Exception {
	this(parseDate(defaultFormat, p_arg),defaultFormat); 
    }
    public TodayNowHelper(Date p_date) { this(p_date,defaultFormat); }

    public String individualFormat(String p_formString) {
	if (p_formString.length()==0) return m_date.toString();
	if (p_formString.equals("long")) return ("Milliseconds since 1.1.1970: " + m_date.getTime());	
	try {
	    SimpleDateFormat sdf = new SimpleDateFormat (p_formString);
	    String st= sdf.format(m_date,new StringBuffer(),new FieldPosition(0)).toString();
	    if (st==null) return new String("individualFormat('"+p_formString+"') returns null");
	    return st;
	} catch(Exception e) {return new String("format not valid: '"+p_formString+"'");}
    }
    public String individualFormat() {
	return m_formatter.format(m_date,new StringBuffer(),new FieldPosition(0)).toString();
    }

    public static Date parseDate(String p_formString, String p_arg) throws Exception {
	/** returns a Date if the String could be parsed or throws an Exception otherwise */    
	SimpleDateFormat sdf = new SimpleDateFormat (p_formString);
	Date dt = sdf.parse(p_arg,new ParsePosition(0));
	if (dt==null) throw new Exception("parseDate('"+p_formString+"','"+p_arg+"') failed");
	return dt;
    }

    public void parseSerDate(String p_formString, String p_arg) throws Exception {
	/** changes the date or throws an Exception otherwise */      
	SimpleDateFormat sdf = new SimpleDateFormat (p_formString);
	m_date = sdf.parse(p_arg,new ParsePosition(0));
    }
    public void parseSerDate(String p_arg) throws Exception {
	/** changes the date or throws an Exception otherwise */      
	m_date = m_formatter.parse(p_arg,new ParsePosition(0));
    }
    public void setFormatter(String p_formString) throws Exception {
	m_formatter = new SimpleDateFormat(p_formString);
    }
    public void setFormatter() throws Exception {
	m_formatter = new SimpleDateFormat(defaultFormat);
    }

    public boolean equals(Object p_object) {
	if(!(p_object instanceof TodayNowHelper)) return false;
	TodayNowHelper sd = (TodayNowHelper) p_object;
	return sd.m_date.equals(m_date);
    }

    private static void tellHow(boolean p_exit) {
	System.out.println("Usage:\n  java TodayNowHelper [-h] [-p DateFormat DateString DateFormats] [DateFormats]");	
	System.out.println("accepted DateFormats: yyyy, yy, MMMM, MMM, MM, dd EEEE, E, HH:mm:ss long");
	System.out.println("without -p option the actual date is shown");
	System.out.println("example: \njava TodayNowHelper -p dd.MM.yy,HH:mm 9.1.00,0:01 \"EEEE dd. MMMM yyyy HH:mm:ss\"");
	System.out.println("results in:\nEEEE dd. MMMM yyyy HH:mm:ss' -  Sonntag 09. Januar 2000 22:01:00");
	if(p_exit) System.exit(0);
    }

    public static void main(String args[]){
	TodayNowHelper mT = new TodayNowHelper(new Date());
	int argCnt=0; // we need that for argument count
	if(args.length==0) System.out.println("Date.toString(): "+mT.individualFormat(""));
	else if(args[0].equals("-h")) tellHow(true);
	else if(args[0].equals("-p")) {
	    if(args.length<4) tellHow(true);
	    try {mT = new TodayNowHelper(args[1],args[2]);
	    } catch(Exception e) {
		System.out.println("The date could not be recognized. Reason:");
		System.out.println(e);
		System.exit(0);
	    }
	    argCnt=3;
	}
	for(;argCnt<args.length;argCnt++)
	    System.out.println(args[argCnt]+"' -  "+mT.individualFormat(args[argCnt]));
    }
}




