#!/bin/bash

theDir=`eval pwd`
export CLASSPATH=.:../lib/servlet.jar
cd $theDir

AppName=${theDir##/*/}
echo AppName=$AppName
SvltDir=/opt/jakarta/tomcat/webapps/examples/WEB-INF/classes
ApltDir=/opt/jakarta/tomcat/webapps/examples/applets

if [[ "$1" = "run" ]]; then
    test -s ${AppName}Con.class &&  java ${AppName}Con
    test -s ${AppName}Gui.class &&  java ${AppName}Gui
    exit 0
fi

if [[ "$1" = "clean" ]]; then
# clean old stuff
    rm -f ${AppName}{Con,Gui,Svlt,Aplt,Helper}.class 2>/dev/null
    rm -f ${AppName}*\$*.class 2>/dev/null
    rm -f ${AppName}*.html 2>/dev/null
    rm -f Helper*.class 2>/dev/null 
    rm TAGS 2>/dev/null
    rm semantic.cache 2>/dev/null
    rm *~ 2>/dev/null
    exit 0
fi

if [[ "$1" = "etags" ]]; then
# clean old stuff
    rm -f ${AppName}{Con,Gui,Svlt,Aplt,Helper}.class 2>/dev/null
    rm -f ${AppName}*\$*.class 2>/dev/null
    rm -f ${AppName}Aplt.html 2>/dev/null
    rm TAGS 2>/dev/null
    rm semantic.cache 2>/dev/null
    rm *~ 2>/dev/null
    etags *
    exit 0
fi

if [[ "$1" = "new" ]]; then
    oldAppName=HelloWorld
    for src in Con Gui Svlt Aplt Helper; do
	test -s ${oldAppName}${src}.java && mv ${oldAppName}${src}.java ${AppName}${src}.java 
    done
    exit 0
fi

if [[ "$1" ]]; then
    echo "Unrecognized option $1. Exit."
    exit 0
fi


# compile
for appType in Con Gui Svlt Aplt Helper; do
    test -s ${AppName}${appType}.java && javac -deprecation ${AppName}${appType}.java
done

test -s ${AppName}Helper.java && javac ${AppName}Helper.java
if ls Helper*.java 2> /dev/null 1> /dev/null; then
    for helpType in Helper*.java; do 
	javac $helpType
    done
fi

# put ${AppName}Svlt.class  to servlet dir on tomcat
# test -s $SvltDir/${AppName}Svlt.class &&  rm -f $SvltDir/${AppName}Svlt.class
test -s ${AppName}Svlt.class &&  cp ${AppName}Svlt.class $SvltDir
test -s ${AppName}Helper.class &&  cp ${AppName}Helper.class $SvltDir
if ls Helper*.java 2> /dev/null 1> /dev/null; then
    for helpType in Helper*.class; do 
	cp $helpType $SvltDir
    done
fi
if ls *.properties 2> /dev/null 1> /dev/null; then
    for props in *.properties; do 
	cp $props $SvltDir
    done
fi

# put ${AppName}Aplt.class to applet dir on tomcat
#test -s $ApltDir/${AppName}Aplt.class &&  rm -f $ApltDir/${AppName}Aplt.class
test -s ${AppName}Aplt.class &&  cp ${AppName}Aplt.class $ApltDir
test -s ${AppName}Helper.class &&  cp ${AppName}Helper.class $ApltDir
if ls Helper*.java 2> /dev/null 1> /dev/null; then
    for helpType in Helper*.class; do 
	cp $helpType $ApltDir
    done
fi
if ls *$*.class 2> /dev/null 1> /dev/null; then
    for subClass in *$*.class; do 
	cp $subClass $ApltDir
    done
fi
if ls *.properties 2> /dev/null 1> /dev/null; then
    for props in *.properties; do 
	cp $props $ApltDir
    done
fi

# create ${AppName}Aplt.html
if test -f ${AppName}Aplt.class; then
    echo "<html><head><title>${AppName}Aplt</title></head>" > ${AppName}Aplt.html
    echo "<!-- The object tag below did work only with Netscape and Mozilla, but not with MS IE on my system ! -->"  >> ${AppName}Aplt.html  
    echo "<body><p><object classid=\"java:${AppName}Aplt.class\" codetyte=\"application/java-vm\" width=\"450\" height=\"300\"></object></p>" >> ${AppName}Aplt.html  
#    echo "<!-- The EMBED tag works only with Netscape and Mozilla, not with MS IE ! -->"  >> ${AppName}Aplt.html  
#    echo "<EMBED type=\"application/x-java-applet;version=1.2.2\"" >> ${AppName}Aplt.html  
#    echo "code=\"${AppName}Aplt.class\" codebase=\".\"" >> ${AppName}Aplt.html 
#    echo "pluginspage=\"http://java.sun.com/products/plugin/1.2/plugin-install.html\"></EMBED>" >> ${AppName}Aplt.html 
    echo "<hr/>This is the ${AppName} applet. " >> ${AppName}Aplt.html 
    echo "<br/>Back to the <a href=\"../index.html\" target=\"_parent\">Example page</a>" >> ${AppName}Aplt.html 
    echo "</body></html>" >> ${AppName}Aplt.html 
fi

# put ${AppName}Aplt.html to applet dir on tomcat
#test -s $ApltDir/${AppName}Aplt.html &&  rm -f $ApltDir/${AppName}Aplt.html
test -s ${AppName}Aplt.html &&  cp ${AppName}Aplt.html $ApltDir

# create ${AppName}.html
if test -f ${AppName}Aplt.class; then
    echo "<html><head><title>${AppName}</title></head>" > ${AppName}.html
    echo "<FRAMESET  COLS=\"50%,*\" bordercolor=#00FFFF framespacing=1 frameborder=1 border=1>" >> ${AppName}.html  
    echo "<FRAME SRC=\"${AppName}Aplt.html\" name=\"applet\">" >> ${AppName}.html 
    echo "<FRAME SRC=\"../servlet/${AppName}Svlt\" name=\"servlet\"></FRAMESET>" >> ${AppName}.html 
    echo "<body></body></html>" >> ${AppName}.html 
fi

# put ${AppName}.html to applet dir on tomcat
#test -s $ApltDir/${AppName}.html &&  rm -f $ApltDir/${AppName}.html
test -s ${AppName}.html &&  cp ${AppName}.html $ApltDir
